==> iutest-1.11.1.zip: iutest-1.11.1/README.md <==
[![Travis-CI Build Status](https://travis-ci.org/srz-zumix/iutest.png?branch=master)](https://travis-ci.org/srz-zumix/iutest)
[![Coverage Status](https://coveralls.io/repos/srz-zumix/iutest/badge.png?branch=master)](https://coveralls.io/r/srz-zumix/iutest?branch=master)  
[![Shippable Build Status](https://api.shippable.com/projects/541904d2ac22859af743f867/badge?branchName=master)](https://app.shippable.com/projects/541904d2ac22859af743f867/builds/latest)
[![wercker status](https://app.wercker.com/status/d385156052aa4118a7f24affe4a8f851/s/master "wercker status")](https://app.wercker.com/project/bykey/d385156052aa4118a7f24affe4a8f851)
[![AppVeyor Build status](https://ci.appveyor.com/api/projects/status/2gdmgo8ce8m0iy0e?svg=true)](https://ci.appveyor.com/project/srz-zumix/iutest)

iutest
==========
iutest - iris unit test framework

Welcome to the iutest
--------------------------------------------------
iutest  framework for writeing C++ tests.

Supports automatic tests discovery, include only, value- and type- parameterized tests,
XML test report, inform- and assume- flavor, and japanese test name, etc...

Documentation
--------------------------------------------------

doc/index.html  
[online document](http://iutest.sourceforge.jp/doc/index.html)  


Project page
--------------------------------------------------

[Project page](http://iutest.sourceforge.jp/)  
[Github](https://github.com/srz-zumix/iutest)  
[Google Group](https://groups.google.com/forum/?fromgroups#!forum/g-iutest)  

    
License
--------------------------------------------------

    Copyright (c) 2011-2015, Takazumi Shirayanagi,
    All rights reserved.

    This software is released under the new(3-clause) BSD License, see LICENSE

==> iutest-1.14.0.zip: iutest-1.14.0/README.md <==
[![Travis-CI Build Status](https://travis-ci.org/srz-zumix/iutest.png?branch=master)](https://travis-ci.org/srz-zumix/iutest)
[![Coverage Status](https://coveralls.io/repos/srz-zumix/iutest/badge.png?branch=master)](https://coveralls.io/r/srz-zumix/iutest?branch=master)
[![codecov.io](http://codecov.io/github/srz-zumix/iutest/coverage.svg?branch=master)](http://codecov.io/github/srz-zumix/iutest?branch=master)  
[![Shippable Build Status](https://api.shippable.com/projects/541904d2ac22859af743f867/badge?branchName=master)](https://app.shippable.com/projects/541904d2ac22859af743f867/builds/latest)
[![wercker status](https://app.wercker.com/status/d385156052aa4118a7f24affe4a8f851/s/master "wercker status")](https://app.wercker.com/project/bykey/d385156052aa4118a7f24affe4a8f851)
[![AppVeyor Build status](https://ci.appveyor.com/api/projects/status/2gdmgo8ce8m0iy0e?svg=true)](https://ci.appveyor.com/project/srz-zumix/iutest)  
[![New(3-clause) BSD License](https://img.shields.io/badge/license-New_BSD-blue.svg)](http://opensource.org/licenses/BSD-3-Clause)

iutest
==========
iutest - iris unit test framework

Welcome to the iutest
--------------------------------------------------
iutest is framework for writing C++ tests.

Supports automatic tests discovery, include only, value- and type- parameterized tests,
XML test report, inform- and assume- flavor, and japanese test name, matchers, etc...

Documentation
--------------------------------------------------

doc/index.html  
[online document](http://iutest.osdn.jp/doc/index.html)  


Project page
--------------------------------------------------

[Project page](http://iutest.osdn.jp/)  
[Github](https://github.com/srz-zumix/iutest)  
[Google Group](https://groups.google.com/forum/?fromgroups#!forum/g-iutest)  

Tools
--------------------------------------------------

[![Circle CI](https://circleci.com/gh/srz-zumix/iutest.svg?style=svg)](https://circleci.com/gh/srz-zumix/iutest)

* fused  
make fused-src.
* twilio  
notifies the test results using twilio
* wandbox  
tools to make use of the iutest in wandbox

Others
--------------------------------------------------

* Support Google Native Client  
[![Magnum CI](https://magnum-ci.com/status/9175310cbf4594b8755634347186515a.png)](https://magnum-ci.com/public/ad50f16d4e6b5c8a578a/builds)


License
--------------------------------------------------

    Copyright (c) 2011-2015, Takazumi Shirayanagi,
    All rights reserved.

    This software is released under the New(3-clause) BSD License, see LICENSE
